capnpy
======

.. image:: https://github.com/antocuni/capnpy/actions/workflows/test.yml/badge.svg
    :target: https://github.com/antocuni/capnpy/actions/workflows/test.yml

A very fast implementation of `Cap’n Proto`_ for CPython and PyPy.

Read the `online docs`_.

.. _`Cap’n Proto`: https://capnproto.org/

.. _`online docs`: http://capnpy.readthedocs.io/
